==> jc-1.4.0.tar.gz: javax/imageio/stream/MemoryCacheImageInputStream.h <==
// public class javax.imageio.stream.MemoryCacheImageInputStream

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl
// @dep_class db0a7ebdd386f1cc javax_imageio_stream_MemoryCacheImageInputStream

// header file dependencies
// @dep_header javax_imageio_stream_ImageInputStreamImpl

#include "javax/imageio/stream/ImageInputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_MemoryCacheImageInputStream_H_
#define _JC_javax_imageio_stream_MemoryCacheImageInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_refs	_jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_nonrefs	_jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$refs	_jc_javax_imageio_stream_MemoryCacheImageInputStream$refs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$nonrefs	_jc_javax_imageio_stream_MemoryCacheImageInputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object	_jc_javax_imageio_stream_MemoryCacheImageInputStream$object;

typedef const struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vmethods	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtable	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vtable;
typedef const struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern void _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
extern void _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$flushBefore$bf21d8a7b8a41c3e(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, jlong);
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$isCached$7eabc2d936c77133(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$isCachedFile$ed19c4c24a1815db(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$isCachedMemory$53b63747781a10df(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
extern jint _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
extern jint _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$flushBefore$bf21d8a7b8a41c3e;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$isCached$7eabc2d936c77133;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$isCachedFile$ed19c4c24a1815db;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$isCachedMemory$53b63747781a10df;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
	void	(*flushBefore$bf21d8a7b8a41c3e)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, jlong);
	jboolean	(*isCached$7eabc2d936c77133)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
	jboolean	(*isCachedFile$ed19c4c24a1815db)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
	jboolean	(*isCachedMemory$53b63747781a10df)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vmethods	javax_imageio_stream_MemoryCacheImageInputStream;
};

// Vtype
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_refs {
	struct _jc_java_io_InputStream$object	*stream;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$refs {
    _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_refs	javax_imageio_stream_MemoryCacheImageInputStream;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_nonrefs	javax_imageio_stream_MemoryCacheImageInputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object {
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype	*vtype;
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype _jc_javax_imageio_stream_MemoryCacheImageInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_MemoryCacheImageInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_MemoryCacheImageInputStream$class_object;

#endif	/* _JC_javax_imageio_stream_MemoryCacheImageInputStream_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/stream/MemoryCacheImageInputStream.h <==
// public class javax.imageio.stream.MemoryCacheImageInputStream

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl
// @dep_class db0a7ebdd386f1cc javax_imageio_stream_MemoryCacheImageInputStream

// header file dependencies
// @dep_header javax_imageio_stream_ImageInputStreamImpl

#include "javax/imageio/stream/ImageInputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_MemoryCacheImageInputStream_H_
#define _JC_javax_imageio_stream_MemoryCacheImageInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_refs	_jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_nonrefs	_jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$refs	_jc_javax_imageio_stream_MemoryCacheImageInputStream$refs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$nonrefs	_jc_javax_imageio_stream_MemoryCacheImageInputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object	_jc_javax_imageio_stream_MemoryCacheImageInputStream$object;

typedef const struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vmethods	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtable	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vtable;
typedef const struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$flushBefore$bf21d8a7b8a41c3e(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, jlong) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$isCached$7eabc2d936c77133(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$isCachedFile$ed19c4c24a1815db(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$isCachedMemory$53b63747781a10df(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_MemoryCacheImageInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$flushBefore$bf21d8a7b8a41c3e;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$isCached$7eabc2d936c77133;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$isCachedFile$ed19c4c24a1815db;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$isCachedMemory$53b63747781a10df;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
	void	(*flushBefore$bf21d8a7b8a41c3e)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, jlong) _JC_JCNI_ATTR;
	jboolean	(*isCached$7eabc2d936c77133)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCachedFile$ed19c4c24a1815db)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCachedMemory$53b63747781a10df)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vmethods	javax_imageio_stream_MemoryCacheImageInputStream;
};

// Vtype
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_refs {
	struct _jc_java_io_InputStream$object	*stream;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$refs {
    _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_refs	javax_imageio_stream_MemoryCacheImageInputStream;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_MemoryCacheImageInputStream$sub_nonrefs	javax_imageio_stream_MemoryCacheImageInputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_MemoryCacheImageInputStream$object {
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype	*vtype;
	_jc_javax_imageio_stream_MemoryCacheImageInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_MemoryCacheImageInputStream$vtype _jc_javax_imageio_stream_MemoryCacheImageInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_MemoryCacheImageInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_MemoryCacheImageInputStream$class_object;

#endif	/* _JC_javax_imageio_stream_MemoryCacheImageInputStream_H_ */
